package Workflow::CMS::ContentData;

use strict;
use warnings;

use Encode;
use MT::AddressBook;

use MT::Util qw( format_ts relative_date );
use Workflow::Util qw( can_workflow use_revision_cd get_lastest_revision_cd get_lastest_revision_object );
use Workflow::App::CMS qw( rest_day is_limit );

use Data::Dumper;

sub cms_pre_preview {
    my ($cb, $app, $obj, $data) = @_;

    my $revision = get_lastest_revision($app);
    return 1 if !$revision;

    $obj->current_revision($revision->rev_number) if $revision;

    my $rev = $obj->load_revision( { rev_number => $revision->rev_number } );
    push @$data,
        {
            data_name => 'status',
            data_value => $rev->[0]->status
    };
}

sub delete_action {
    my ($cb, $app, $param, $tmpl) = @_;

    return if !can_workflow($app);

    $param->{use_actions} = 0;
}

sub preview_entry {
    my ($cb, $app, $template) = @_;

    return if !can_workflow($app);

    my $old;
    my $new;

    $old = <<HTML;
  <button
     mt:mode="save_entry"
     type="submit"
     name="save"
     value="save"
     accesskey="s"
     title="<\$mt:var name="save_button_title"\$>"
     class="save action primary button">
    <mt:var name="save_button_value">
  </button>
HTML
    $old = quotemeta($old);

    $new = <<HTML;
HTML

    $$template =~ s/$old//;

}

sub list_revision {
    my ($cb, $app, $terms, $args, $param, $hasher) = @_;

    return if !can_workflow($app);

    my $q = $app->param;
    my $r = $q->param('r');

    my $type = $q->param('_type');
    my $content_type_id;
if ( $type eq 'content_data' ) {
    $type = 'cd';
    $content_type_id = $q->param('content_type_id');
}
    my $id = $terms->{entry_id};
if ( $type eq 'cd' ) {
    $id = $terms->{cd_id};
}
    my $obj = MT->instance->model($type)->load($id);
    my $blog = $app->blog;
    my $lang  = $app->user ? $app->user->preferred_language : undef;
    my %users;
    my $js = $param->{rev_js};
    unless ($js) {
        $js
            = "location.href='"
            . $app->uri
            . '?__mode=view&amp;_type='
            . $app->param('_type');
        if ( my $id = $obj->id ) {
            $js .= '&amp;id=' . $id;
        }
        if ( defined $blog ) {
            $js .= '&amp;blog_id=' . $blog->id;
        }
        if ( $type eq 'cd' ) {
            $js .= '&amp;content_type_id=' . $obj->content_type_id;
        }
    }

    $$hasher = sub {
        my ( $rev, $row ) = @_;

        if ( my $ts = $rev->created_on ) {
            $row->{created_on_formatted}
                = format_ts( MT::App::CMS::LISTING_DATE_FORMAT(),
                $ts, $blog, $lang );
            $row->{created_on_time_formatted}
                = format_ts( MT::App::CMS::LISTING_TIMESTAMP_FORMAT(),
                $ts, $blog, $lang );
            $row->{created_on_relative} = relative_date( $ts, time, $blog );
        }
        if ( $row->{created_by} ) {
            my $created_user = $users{ $row->{created_by} }
                ||= MT::Author->load( $row->{created_by} );
            if ($created_user) {
                $row->{created_by} = $created_user->nickname;
            }
            else {
                $row->{created_by} = $app->translate('(user deleted)');
            }
        }
        my $revision    = $obj->object_from_revision($rev);
        my $column_defs = $obj->column_defs;

        if ( ( 'entry' eq $type ) || ( 'page' eq $type ) || ( 'cd' eq $type )) {
            $row->{rev_status} = $revision->[0]->status;
        }
        $row->{rev_js}  = $js . '&amp;r=' . $row->{rev_number} . "'";

        my ($terms, $args);
if ( $type eq 'cd' ) {
    $terms->{'cd_id'} = $revision->[0]->id;
} else {
    $terms->{'entry_id'} = $revision->[0]->id;
}
        $args->{sort} = 'rev_number';
        $args->{direction} = 'descend';
        $args->{limit} = 1;
        my $rev_model = MT->instance->model($type.':revision');
        my @revs = $rev_model->load($terms, $args);
        $rev = shift @revs || undef;

        if ($r) {
            $row->{is_current} = $r == $row->{rev_number};
        } else {
            $row->{is_current} = $rev->rev_number == $row->{rev_number};
        }
    };

}

sub set_entry_param {
    my ($cb, $app, $param, $tmpl) = @_;
#    my $author = $app->user;

    return 1 if $app->param('_autosave');
    return 1 if $app->permissions->can_administer_site();
    return 1 if !$app->param('id');

    my $reviewee = $app->can_do('request_entry_approval');
    my $reviewer = $app->can_do('approve_entry');

    my $q = $app->param;
    my $type = $q->param('_type');
if ( $type eq 'content_data' ) {
    $type = 'cd';
}
    my $id = $q->param('id');
    my $model = $app->model($type);
    my $rev_model = $app->model($type.':revision');
    return 1 unless $rev_model;

    my $obj;
    my $before_status;
    my ($terms, $args);
###############################################
    $terms->{cd_id} = $id;
###############################################
    $args->{sort} = 'rev_number';
    $args->{direction} = 'descend';

###############################################
    my $blog = $app->blog;
###############################################

    my $content_data;

    ### preview bug fix
    if (!$q->param('reedit') && !$param->{error}) {
    ###
    my $use_revision = use_revision_cd($app);
    if ($use_revision) {
        $args->{limit} = 1;
        my @revs = $rev_model->load($terms, $args);

        my $revision = shift @revs || undef;
        if ($revision) {
            my $revision_number = $q->param('r') ? $q->param('r') : $revision->rev_number;

            my @objs = $model->load($id);
            $obj = shift @objs || undef;
            my $rev = $obj->load_revision( { rev_number => $revision_number } );
            if ( $rev && @$rev ) {
                $content_data = $rev->[0];

                my $values = $content_data->get_values;
                $param->{$_} = $values->{$_} for keys %$values;
$param->{data_label} = $param->{label};
                $param->{loaded_revision} = 1;

###############################################
    my $content_type_id = $app->param('content_type_id')
        or return $app->errtrans("Invalid request.");

    my $content_type = MT::ContentType->load($content_type_id)
        or return $app->errtrans('Invalid request.');

    my $array           = $content_type->fields;
    my $ct_unique_id    = $content_type->unique_id;
    my $content_data_id = $app->param('id');

    if ($content_data_id) {
#        $content_data = MT::ContentData->load(
#            {   id              => $content_data_id,
#                blog_id         => $content_type->blog_id,
#                content_type_id => $content_type->id,
#            }
#            )
#            or return $app->error(
#            $app->translate(
#                'Load failed: [_1]',
#                MT::ContentData->errstr
#                    || $app->translate('(no reason given)')
#            )
#            );
#        if ( $use_revision ) {
#
#            my $original_revision = $content_data->revision;
#            my $rn                = $app->param('r');
#            if ( defined $rn && $rn != $content_data->current_revision ) {
#
#                my $status_text
#                    = MT::Entry::status_text( $content_data->status );
#                $param->{current_status_text} = $status_text;
#                $param->{current_status_label}
#                    = $app->translate($status_text);
#                my $rev
#                    = $content_data->load_revision( { rev_number => $rn } );
#                if ( $rev && @$rev ) {
#                    $content_data = $rev->[0];
#
#                    my $values = $content_data->get_values;
#                    $param->{$_} = $values->{$_} for keys %$values;
#                    $param->{loaded_revision} = 1;
#                }
#                $param->{rev_number} = $rn;
#                $param->{no_snapshot} = 1 if $app->param('no_snapshot');
#            }
#            $param->{rev_date} = MT::Util::format_ts(
#                '%Y-%m-%d %H:%M:%S',
#                $content_data->modified_on,
#                $blog, $app->user ? $app->user->preferred_language : undef
#            );
#        }

        $param->{identifier}
            = $app->param('identifier') || $content_data->identifier;

#        my $status = $app->param('status') || $content_data->status;
#        $status =~ s/\D//g;
#        $param->{status} = $status;
#        $param->{ 'status_' . MT::Entry::status_text($status) } = 1;

        $param->{content_data_permalink}
            = MT::Util::encode_html( $content_data->permalink );

        $param->{authored_on_date} = $app->param('authored_on_date')
            || MT::Util::format_ts( '%Y-%m-%d', $content_data->authored_on,
            $blog, $app->user ? $app->user->preferred_language : undef );
        $param->{authored_on_time} = $app->param('authored_on_time')
            || MT::Util::format_ts( '%H:%M:%S', $content_data->authored_on,
            $blog, $app->user ? $app->user->preferred_language : undef );
        $param->{unpublished_on_date} = $app->param('unpublished_on_date')
            || MT::Util::format_ts( '%Y-%m-%d', $content_data->unpublished_on,
            $blog, $app->user ? $app->user->preferred_language : undef );
        $param->{unpublished_on_time} = $app->param('unpublished_on_time')
            || MT::Util::format_ts( '%H:%M:%S', $content_data->unpublished_on,
            $blog, $app->user ? $app->user->preferred_language : undef );
    }

    my $data = $content_data->data if $content_data;
    my $convert_breaks
        = $content_data
        ? MT::Serialize->unserialize( $content_data->convert_breaks )
        : undef;
    my $blockeditor_data
        = $content_data
        ? $content_data->block_editor_data()
        : undef;
    my $content_field_types = $app->registry('content_field_types');
    @$array = map {
        my $e_unique_id = $_->{unique_id};
        my $can_edit_field
            = $app->permissions->can_do( 'content_type:'
                . $ct_unique_id
                . '-content_field:'
                . $e_unique_id );
        if (   $can_edit_field
            || $app->permissions->can_do('edit_all_content_data') )
        {
            $_->{can_edit} = 1;
        }
        $_->{content_field_id} = $_->{id};
        delete $_->{id};

        if ( $app->param( $_->{content_field_id} ) ) {
            $_->{value} = $app->param( $_->{content_field_id} );
        }
        elsif ( $content_data_id || $data ) {
            $_->{value} = $data->{ $_->{content_field_id} };
        }
        else {
            # TODO: fix after updating values option.
            if ( $_->{type} eq 'select_box' || $_->{type} eq 'checkboxes' ) {
                my $delimiter = quotemeta( $_->{options_delimiter} || ',' );
                my @values = split $delimiter,
                    ( $_->{options}{initial_value} || '' );
                $_->{value} = \@values;
            }
            else {
                $_->{value} = $_->{options}{initial_value};
            }
        }

        my $content_field_type = $content_field_types->{ $_->{type} };

        if ( my $field_html_params
            = $content_field_type->{field_html_params} )
        {
            if ( !ref $field_html_params ) {
                $field_html_params
                    = MT->handler_to_coderef($field_html_params);
            }
            if ( 'CODE' eq ref $field_html_params ) {
                $field_html_params = $field_html_params->( $app, $_ );
            }

            if ( ref $field_html_params eq 'HASH' ) {
                for my $key ( keys %{$field_html_params} ) {
                    unless ( exists $_->{$key} ) {
                        $_->{$key} = $field_html_params->{$key};
                    }
                }
            }
        }

        if ( my $field_html = $content_field_type->{field_html} ) {
            if ( !ref $field_html ) {
                if ( $field_html =~ /\.tmpl$/ ) {
                    my $plugin = $content_field_type->{plugin};
                    $field_html
                        = $plugin->id eq 'core'
                        ? $app->load_tmpl($field_html)
                        : $plugin->load_tmpl($field_html);
                    $field_html = $field_html->text if $field_html;
                }
                else {
                    $field_html = MT->handler_to_coderef($field_html);
                }
            }
            if ( 'CODE' eq ref $field_html ) {
                $_->{field_html} = $field_html->( $app, $_ );
            }
            else {
                $_->{field_html} = $field_html;
            }
        }

        $_->{data_type} = $content_field_types->{ $_->{type} }{data_type};
        if ( $_->{type} eq 'multi_line_text' ) {
            if ( $convert_breaks
                && exists $$convert_breaks->{ $_->{content_field_id} } )
            {
                $_->{convert_breaks}
                    = $$convert_breaks->{ $_->{content_field_id} };
            }
            else {
                $_->{convert_breaks} = $_->{options}{input_format};
            }
        }
        $_;
    } @$array;

    $param->{fields} = $array;
    if ($blockeditor_data) {
        $param->{block_editor_data} = $blockeditor_data;
    }

    foreach
        my $name (qw( saved_added saved_changes err_msg content_type_id id ))
    {
        $param->{$name} = $app->param($name) if $app->param($name);
    }

    $param->{new_object}          = $content_data_id ? 0 : 1;
    $param->{object_label}        = $content_type->name;
    $param->{sitepath_configured} = $blog && $blog->site_path ? 1 : 0;

    ## Load text filters if user displays them
    my $filters = MT->all_text_filters;
    $param->{text_filters} = [];
    for my $filter ( keys %$filters ) {
        if ( my $cond = $filters->{$filter}{condition} ) {
            $cond = MT->handler_to_coderef($cond) if !ref($cond);
            next unless $cond->('content-type');
        }
        push @{ $param->{text_filters} },
            {
            filter_key   => $filter,
            filter_label => $filters->{$filter}{label},
            filter_docs  => $filters->{$filter}{docs},
            };
    }
    $param->{text_filters} = [ sort { $a->{filter_key} cmp $b->{filter_key} }
            @{ $param->{text_filters} } ];
    unshift @{ $param->{text_filters} },
        {
        filter_key   => '0',
        filter_label => $app->translate('None'),
        };

    $app->setup_editor_param($param);

    $param->{basename_limit} = ( $blog ? $blog->basename_limit : 0 ) || 30;
###############################################


            }

            # XV̕Ɍ݂̃Xe[^Xɓւ
            if ( $rev && @$rev ) {
                if ($q->param('r')) {
                    my @objs2 = $model->load($id);
                    my $obj2 = shift @objs2 || undef;
                    my $rev2 = $obj2->load_revision( { rev_number => $revision->rev_number } );
                    my $obj3 = $rev2->[0] if ( $rev2 && @$rev2 );
                    $param->{status} = $obj3->status;
                    $param->{rev_number} = $q->param('r');
                    if ($revision->rev_number == $q->param('r')) {
                        $param->{loaded_revision} = 0;
                    } else {
                        $param->{loaded_revision} = 1;
                    }
                }
            }

            $before_status = $content_data->status;

            $param->{'saved_snapshot'} = 1 if $q->param('saved_snapshot');
            $param->{'resend_mail'} = 1 if $q->param('resend_mail');
            $param->{'send_preview'} = 1 if $q->param('send_preview');
        }
    } else {
        my @objs = $model->load($id);
        $obj = shift @objs || undef;

        if ($q->param('r')) {
            my $rev = $obj->load_revision( { rev_number => $q->param('r') } );
            if ( $rev && @$rev ) {
                $obj = $rev->[0];
                $param->{rev_date} = format_ts( "%Y-%m-%d %H:%M:%S",
                    $obj->modified_on, $app->blog,
                    $app->user ? $app->user->preferred_language : undef ) if $obj;
            }
        }
    }

    ### preview bug fix
    } else {
        my $revision = get_lastest_revision_cd($app);
        my $content_data = get_lastest_revision_object($app, $revision) if $revision;
        $before_status = $content_data->status if $content_data;
    }
    ###
    if ( $param->{status} ) {

        # JԂł̗ꗗ̕status_draftɒlݒ肳Ȃs̑Ώ
        if ($param->{status} == 1) {
            $param->{status_draft} = 1;
        }
        # JԂł̗ꗗ̕status_publishɒlݒ肳Ȃs̑Ώ
        if ($param->{status} == 2) {
            $param->{status_publish} = 1;
        }

        if ($param->{status} == 3) {
            $param->{status_review} = 1;
        }
        if ($param->{status} == 10 || $param->{status} == 40) {
            $param->{status_publish_draft} = 1;
            $param->{status_draft} = 0;
            $param->{status_review} = 0;
        }
        if ($param->{status} == 20) {
            $param->{status_publish_review} = 1;
            $param->{status_draft} = 0;
            $param->{status_review} = 0;
        }
if ($param->{status} == 4) {
    $param->{status_publish_review} = 0;
    $param->{status_draft} = 0;
    $param->{status_review} = 0;
    $param->{status_publish_scheduled} = 1;
}
if ($param->{status} == 110 || $param->{status} == 120) {
    $param->{status_publish_review} = 0;
    $param->{status_draft} = 0;
    $param->{status_review} = 0;
    $param->{status_publish} = 0;
    $param->{status_publish_publish_scheduled} = 1;
}

        ### preview bug fix
        if ($reviewer && $q->param('reedit')) {
            if ($param->{status} == 10 || $param->{status} == 20) {
                $param->{status_publish} = 1;
            }
        }
        ###
    }

    # G[̏ꍇ,G[O̓e𔽉f邽ߍXV͗pȂ
    if ( $param->{error} && $param->{status} ) {
        $param->{status_draft} = 0;
        $param->{status_review} = 0;
        $param->{status_publish} = 0;
        $param->{status_publish_draft} = 0;
        $param->{status_publish_review} = 0;

        # C^[
        if ( $reviewee ) {

            # VK쐬܂͖J́uJiejvuJiF҂jvG[́uJiejvɖ߂
            if ($param->{status} == 1 || $param->{status} == 3) {
                $param->{route} = 1;
                $param->{status} = 1;
                $param->{status_draft} = 1;
            }

            # uJvł́uJijvG[́uJvɖ߂
            # JX^tB[hɂĂsave_snapshot_wfȂ̂ŃG[ɂȂȂ
            if ($param->{status} == 2) {
                $param->{route} = 3;
                $param->{status} = 2;
                $param->{status_publish} = 1;
            }

            # uJijvł́uJijvuJiF҂jvG[́uJijvɖ߂
            if ($param->{status} == 10 || $param->{status} == 20) {
                $param->{route} = 4;
                $param->{status} = 2;
                $param->{status_publish_draft} = 1;
            }
        }

        # F
        if ( $reviewer ) {

            # J́uFvu߂vG[́uJiF҂jvɖ߂
            if (( $param->{status} == 1 || $param->{status} == 2 ) && $before_status == 3 ) {
                $param->{route} = 5;
                $param->{status_review} = 1;
            }

            # J́uFvu߂vG[́uJiF҂jvɖ߂
            if (( $param->{status} == 2 || $param->{status} == 40 ) && $before_status == 20 ) {
                $param->{route} = 6;
                $param->{status_publish_review} = 1;
            }
        }
    }

    my $plugin = MT->component('Workflow');
    $param->{rest_day} = $plugin->translate('can use [_1]', rest_day());

    1;
}

sub add_status_for_revision {
    my ($cb, $app, $template) = @_;

    my $old;
    my $new;

    $old = <<HTML;
<mt:var name="pager" value="\$hide_pager" default="0">
HTML
    $old = quotemeta($old);

    $new = <<HTML;
<style type="text/css">
.list-revision-dialog .col.status {
    width: 22%;
}
</style>
<mt:var name="pager" value="\$hide_pager" default="0">
HTML

    $$template =~ s/$old/$new/;

    $old = <<HTML;
<mt:if name="object_type" like="(entry|page|cd)">
HTML
    $old = quotemeta($old);

    $new = <<HTML;
<mt:if name="object_type" like="(entry|page|content_data)">
HTML

    $$template =~ s/$old/$new/g;

    $old = <<HTML;
      <mt:if name="rev_status" eq="1">
        <span class="icon-left-wide icon-draft"><__trans phrase="Draft"></span>
      <mt:else name="rev_status" eq="3">
        <span class="icon-left-wide icon-warning"><__trans phrase="Review"></span>
      <mt:else name="rev_status" eq="4">
        <span class="icon-left-wide icon-future"><__trans phrase="Scheduled"></span>
      <mt:else name="rev_status" eq="2">
        <span class="icon-left-wide icon-success"><__trans phrase="Published"></span>
      <mt:else name="rev_status" eq="5">
        <span class="icon-left-wide icon-spam"><__trans phrase="Spam"></span>
      <mt:else name="rev_status" eq="6">
        <span class="icon-left-wide icon-unpublish"><__trans phrase="Unpublished (End)"></span>
HTML
    $old = quotemeta($old);

    my $plugin = MT->component('Workflow');
    my $text_status_publish_draft =  $plugin->translate('Published (Draft)');
    my $text_status_publish_review =  $plugin->translate('Published (Review)');
    my $text_status_publish_no_approval =  $plugin->translate('No Approval');

    $new = <<HTML;
      <mt:if name="rev_status" eq="1">
        <span class="icon-left-wide icon-draft"><__trans phrase="Draft"></span>
      <mt:else name="rev_status" eq="3">
        <span class="icon-left-wide icon-warning"><__trans phrase="Review"></span>
      <mt:else name="rev_status" eq="4">
        <span class="icon-left-wide icon-future"><__trans phrase="Scheduled"></span>
      <mt:else name="rev_status" eq="2">
        <span class="icon-left-wide icon-success"><__trans phrase="Published"></span>
      <mt:else name="rev_status" eq="5">
        <span class="icon-left-wide icon-spam"><__trans phrase="Spam"></span>
      <mt:else name="rev_status" eq="6">
        <span class="icon-left-wide icon-unpublish"><__trans phrase="Unpublished (End)"></span>
      <mt:else name="rev_status" eq="10">
        <span class="icon-left-wide2 icon-success-draft"> $text_status_publish_draft</span>
      <mt:else name="rev_status" eq="20">
        <span class="icon-left-wide2 icon-success-review"> $text_status_publish_review</span>
      <mt:else name="rev_status" eq="40">
        <span class="icon-left-wide2 icon-success-draft"> $text_status_publish_no_approval</span>
HTML

    $$template =~ s/$old/$new/;
}

sub add_status_for_list {
    my $cb = shift;
    my ( $app, $res, $objs ) = @_;
    my $type = 'content_data';

    for my $data (@{$res->{objects}}) {
        my $model = $app->model($type);
        my $rev_model = $app->model($type.':revision');
        return 1 unless $rev_model;

        my ($terms, $args);
        $terms->{cd_id} = $data->[0];
        $args->{sort} = 'rev_number';
        $args->{direction} = 'descend';
        $args->{limit} = 1;
        my @revs = $rev_model->load($terms, $args);
        my $revision = shift @revs || undef;

        my $entry;
        if ($revision) {
            my @objs = $model->load($data->[0]);
            my $obj = shift @objs || undef;
            my $rev = $obj->load_revision( { rev_number => $revision->rev_number } );
            if ( $rev && @$rev ) {
                $entry = $rev->[0];
            }
        }
        if ($entry) {
            my $static_uri = MT->static_path;
my $status;
    $status = $entry->status;
            for (my $i=1; $i<=2; $i++) {
                if ($status == 10) {
                    $data->[$i] =~ s!icon status published!icon status publish_draft!;
                    $data->[$i] =~ s!</svg>!</svg><svg title="Published" role="img" class="mt-icon mt-icon--sm mt-icon--publish-draft"><use xlink:href="${static_uri}images/sprite.svg#ic_statusdraft"></svg></a>!;
                } elsif ($status == 40) {
                    $data->[$i] =~ s!icon status published!icon status publish_draft!;
                    $data->[$i] =~ s!</svg>!</svg><svg title="Published" role="img" class="mt-icon mt-icon--sm mt-icon--publish-draft"><use xlink:href="${static_uri}images/sprite.svg#ic_statusdraft"></svg></a>!;
                } elsif ($status == 20) {
                    $data->[$i] =~ s!icon status published!icon status publish_review!;
                    $data->[$i] =~ s!</svg>!</svg><svg title="Published" role="img" class="mt-icon mt-icon--sm mt-icon--publish-review"><use xlink:href="${static_uri}images/sprite.svg#ic_error"></svg>!;
                }
            }
        }
    }
}

sub add_status {
    my ($cb, $app, $template) = @_;

    my $old;
    my $new;

if ( $app->user->is_superuser ) {
    $old = <<HTML;
    <mt:if name="status_review">
      <option value="3" selected="selected"><__trans phrase="Unpublished (Review)"></option>
    <mt:else name="status_spam">
HTML
    $old = quotemeta($old);

    $new = <<HTML;
    <mt:if name="status_spam">
HTML
    $$template =~ s/$old/$new/;
}

    return if $app->permissions->can_administer_site();

    return if !use_revision_cd($app);
    my $reviewee = $app->can_do('request_entry_approval');
    my $reviewer = $app->can_do('approve_entry');

    my $plugin = MT->component('Workflow');
    my $publish_status_draft = $plugin->translate('Published (Draft)');
    my $publish_status_review = $plugin->translate('Published (Review)');
my $published_status_scheduled = $plugin->translate('Published (Scheduled)');
my $status_publish_sheduled =  $plugin->translate('Published (Scheduled)');

#############
    $old = <<HTML;
    <a href="<mt:var name="script_url">?__mode=list_revision&_type=cd&id=<\$mt:var name="id" escape="url"\$>&blog_id=<\$mt:var name="blog_id"\$>&r=<mt:var name="rev_number" escape="html">" class="mt-open-dialog mt-modal-open" data-mt-modal-large title="<__trans phrase="View revisions of this [_1]" params="<mt:var name="object_label">">">
      <__trans phrase="View revisions">
    </a>
HTML
    $old = quotemeta($old);

    $new = <<HTML;
    <a href="<mt:var name="script_url">?__mode=list_revision&_type=cd&id=<mt:var name="id" escape="url">&blog_id=<mt:var name="blog_id">&content_type_id=<mt:var name="content_type_id" escape="url">&r=<mt:var name="rev_number" escape="html">" class="mt-open-dialog mt-modal-open" data-mt-modal-large title="<__trans phrase="View revisions of this [_1]" params="<mt:var name="object_label">">">
      <__trans phrase="View revisions">
    </a>
HTML
    $$template =~ s/$old/$new/;
#############


##################### MT6
    $old = <<HTML;
  <mt:unless name="new_object">
    <mt:if name="status_draft">
    <span class="icon-left-wide icon-draft"><__trans phrase="Unpublished (Draft)"></span>
    <mt:else name="status_review">
    <span class="icon-left-wide icon-warning"><__trans phrase="Unpublished (Review)"></span>
    <mt:else name="status_future">
    <span class="icon-left-wide icon-future"><__trans phrase="Scheduled"></span>
    <mt:else name="status_publish">
    <span class="icon-left-wide icon-success"><__trans phrase="Published"></span>
    <mt:else name="status_spam">
    <span class="icon-left-wide icon-spam"><__trans phrase="Unpublished (Spam)"></span>
    <mt:else name="status_unpublish">
    <span class="icon-left-wide icon-unpublish"><__trans phrase="Unpublished (End)"></span>
    </mt:if>
  </mt:unless>
HTML
##################### MT6
    $old = quotemeta($old);

    $new = <<HTML;
  <mt:unless name="new_object">
    <mt:if name="status_draft">
    <span class="icon-left-wide icon-draft"><__trans phrase="Unpublished (Draft)"></span>
    <mt:else name="status_review">
    <span class="icon-left-wide icon-warning"><__trans phrase="Unpublished (Review)"></span>
    <mt:else name="status_future">
    <span class="icon-left-wide1 icon-future"><__trans phrase="Scheduled"></span>
    <mt:else name="status_publish_draft">
    <span class="icon-left-wide2 icon-success-draft">$publish_status_draft</span>
    <mt:else name="status_publish_review">
    <span class="icon-left-wide2 icon-success-review">$publish_status_review</span>
    <mt:else name="status_publish">
    <span class="icon-left-wide icon-success"><__trans phrase="Published"></span>
    <mt:else name="status_spam">
    <span class="icon-left-wide icon-spam"><__trans phrase="Unpublished (Spam)"></span>
    <mt:else name="status_unpublish">
    <span class="icon-left-wide icon-unpublish"><__trans phrase="Unpublished (End)"></span>
    <mt:else name="status_publish_publish_scheduled">
    <span class="icon-left-wide2 icon-publish-future"> $status_publish_sheduled</span>
    </mt:if>
  </mt:unless>
HTML

    $$template =~ s/$old/$new/;

    $old = <<HERE;
<mt:include name="layout/default.tmpl">HERE
    $old = quotemeta($old);
    $new = <<HERE;
<mt:include name="layout/default.tmpl">
<div style="margin-top:20px">
<mt:var name="rest_day">
</div>
HERE
        $$template =~ s!$old!$new!;

#    return if !can_workflow($app);

    $old = <<HERE;
    <mt:setvar name="publish_button_text" value="<__trans phrase="Publish">">
    <mt:setvarblock name="publish_button_title"><__trans phrase="Publish this [_1]" params="<mt:var name="object_label">" escape="html"></mt:setvarblock>
HERE
    $old = quotemeta($old);
    $new = <<HERE;
    <mt:setvar name="publish_button_text" value="<__trans phrase="Publish">">
    <mt:setvarblock name="publish_button_title"><__trans phrase="Publish this [_1]" params="<mt:var name="object_label">" escape="html"></mt:setvarblock>
    <mt:setvar name="review_button_text" value="<__trans phrase="Review">">
    <mt:setvarblock name="review_button_title"><__trans phrase="Review this [_1]" params="<mt:var name="object_label">" escape="html"></mt:setvarblock>
    <mt:setvar name="update_button_text" value="<__trans phrase="Update">">
    <mt:setvarblock name="update_button_title"><__trans phrase="Update this [_1]" params="<mt:var name="object_label">" escape="html"></mt:setvarblock>
HERE
##################### MT6
    $$template =~ s!$old!$new!g;
##################### MT6
    $old = <<HTML;
  </mt:if>
  <mt:if name="loaded_revision">
HTML
    $old = quotemeta($old);

    $new = <<HTML;
</mt:if>
<mt:if name="loaded_revision">
  <mt:if name="status_publish_draft">
    <mt:var name="current_status_text" value="success-draft icon-left-wide2">
    <mt:setvarblock name="current_status_label" value="">$publish_status_draft</mt:setvarblock>
  <mt:else name="status_publish_review">
    <mt:var name="current_status_text" value="success-review icon-left-wide2">
    <mt:setvarblock name="current_status_label" value="">$publish_status_review</mt:setvarblock>
  </mt:if>
HTML
# no change
#    $$template =~ s/$old/$new/;

    $old = <<HTML;
<mt:setvarblock name="related_content">
HTML
    $old = quotemeta($old);

    $new = <<HTML;
<mt:setvarblock name="related_content" append="1">
<mtapp:widget
   id="entry-status-widget"
   class="status-widget"
   label="<__trans phrase="Status">">
  <mt:if name="new_object">
  <mt:else>
  <div class="revision-info">
      <mt:if name="rev_date">
    <p><__trans phrase="Revision: <strong>[_1]</strong>" params="<mt:var name="rev_date" escape="html">"></p>
    <a href="<mt:var name="script_url">?__mode=list_revision2&_type=<mt:var name="object_type" default="link">&id=<mt:var name="id" escape="url">&blog_id=<mt:var name="blog_id">&r=<mt:var name="rev_number" escape="html">" class="mt-open-dialog" title="<__trans phrase="View revisions of this [_1]" params="<mt:var name="object_label">">"><__trans phrase="View revisions"></a>
      <mt:else>
    <p class="zero-state"><__trans phrase="No revision(s) associated with this [_1]" params="<mt:var name="object_label" lower_case="1" escape="html">"></p>
      </mt:if>
  </div>
  <ul>
    <li><__trans phrase="[_1] - Created by [_2]" params="<mt:date ts="\$created_on_ts" relative="1" _default="\$created_on_formatted" format="%b %e %Y">%%<mt:var name="created_by" escape="html" escape="html">"></li>
      <mt:if name="status_publish">
    <li><__trans phrase="[_1] - Published by [_2]" params="<MTDate ts="\$authored_on_ts" relative="1" _default="\$authored_on_formatted" format="%b %e %Y">%%<mt:var name="author_name" escape="html" escape="html">"></li>
      </mt:if>
      <mt:if name="modified_by">
    <li><__trans phrase="[_1] - Edited by [_2]" params="<MTDate ts="\$modified_on_ts" relative="1" _default="\$modified_on_formatted" format="%b %e %Y">%%<mt:var name="modified_by" escape="html" escape="html">"></li>
      </mt:if>
  </ul>
  </mt:if>
</mtapp:widget>
</mt:setvarblock>
<mt:setvarblock name="related_content">
HTML
    $$template =~ s/$old/$new/;

    $old = <<HTML;
<div id="msg-block">
HTML
    $old = quotemeta($old);

    my $resend_mail = $plugin->translate('Resend Mail.');
    my $send_preview = $plugin->translate('Send Preview.');
    my $publish_draft = $plugin->translate('Publish Draft.');
    my $publish_review = $plugin->translate('Publish Review.');

    $new = <<HTML;
<div id="msg-block">
<mt:if name="resend_mail">
  <mtapp:statusmsg
     id="resend-mail"
     class="success">
     $resend_mail
  </mtapp:statusmsg>
</mt:if>
<mt:if name="send_preview">
  <mtapp:statusmsg
     id="send-preview"
     class="success">
     $send_preview
  </mtapp:statusmsg>
</mt:if>
<mt:if name="saved_snapshot">
<mt:if name="status_publish_draft">
  <mtapp:statusmsg
     id="resend-mail"
     class="success">
     $publish_draft
  </mtapp:statusmsg>
<mt:else name="status_publish_review">
  <mtapp:statusmsg
     id="resend-mail"
     class="success">
     $publish_review
  </mtapp:statusmsg>
<mt:else name="status_publish_publish_scheduled">
  <mtapp:statusmsg
     id="resend-mail"
     class="success">
     $publish_review
  </mtapp:statusmsg>
</mt:if>
</mt:if>

HTML
    $$template =~ s/$old/$new/;

    if ($reviewee) {

# 폜ACR\
       $old = <<HERE;
<div class="delete-action">
  <a
     href="javascript:void(0)"
     mt:command="do-remove-items"
     mt:object-singular="<mt:var name="object_label" lower_case="1" escape="html">"
     mt:object-plural="<mt:var name="object_label_plural" lower_case="1" escape="html">"
     mt:object-type="<mt:var name="object_type" escape="html">" mt:blog-id="<mt:var name="blog_id">"
     type="submit"
     title="<mt:var name="delete_button_title">"
     class="delete"
     accesskey="x">
    <__trans phrase="Delete">
  </a>
</div>
HERE

    $old = quotemeta($old);
    $$template =~ s!$old!!;

##################### MT6
        $old = <<HERE;
    <select name="status" id="status" class="custom-select form-control full" onchange="highlightSwitch(this)">
      <option value="1"<mt:if name="status_draft"> selected="selected"</mt:if>><__trans phrase="Unpublished (Draft)"></option>
      <option value="2"<mt:if name="status_publish"> selected="selected"</mt:if>><__trans phrase="Published"></option>
    <mt:if name="status_review">
      <option value="3" selected="selected"><__trans phrase="Unpublished (Review)"></option>
    <mt:else name="status_spam">
      <option value="5" selected="selected"><__trans phrase="Unpublished (Spam)"></option>
    </mt:if>
    <mt:if name="new_object">
      <option value="4"<mt:if name="status_future"> selected="selected"</mt:if>><__trans phrase="Scheduled"></option>
    <mt:else>
      <mt:unless name="status_publish">
      <option value="4"<mt:if name="status_future"> selected="selected"</mt:if>><__trans phrase="Scheduled"></option>
      </mt:unless>
    </mt:if>
    <mt:if name="status_unpublish">
      <option value="6" selected="selected"><__trans phrase="Unpublished (End)"></option>
    </mt:if>
    </select>
HERE
##################### MT6
    $old = quotemeta($old);
    $new = <<HERE;
<mt:SetVar name="hidden_button" value="0" />
<mt:if name="status_review">
  <mt:SetVar name="hidden_button" value="1" />
</mt:if>
<mt:if name="status_publish_review">
  <mt:SetVar name="hidden_button" value="1" />
</mt:if>
<mt:if name="status_publish_scheduled">
  <mt:SetVar name="hidden_button" value="1" />
</mt:if>
<mt:if name="status_publish_publish_scheduled">
  <mt:SetVar name="hidden_button" value="1" />
</mt:if>
<__trans_section component="Workflow">
    <select<mt:if name="hidden_button"> disabled="disabled"</mt:if> name="status" id="status" class="custom-select form-control full" onchange="highlightSwitch(this)">
    <mt:if name="status_draft">
      <option value="1"<mt:if name="status_draft"> selected="selected"</mt:if>><__trans phrase="Unpublished (Draft)"></option>
      <option value="3"><__trans phrase="Unpublished (Review)"></option>
    <mt:else name="status_review">
      <option value="3"><__trans phrase="Unpublished (Review)"></option>
    <mt:else name="status_publish_draft">
      <option value="10" selected="selected"><__trans phrase="Published (Draft)"></option>
      <option value="20"><__trans phrase="Request Approve after Publish"></option>
    <mt:else name="status_publish_review">
      <option value="20"><__trans phrase="Published (Review)"></option>
    <mt:else name="status_publish">
      <mt:if name="new_object">
        <option value="1"<mt:if name="status_draft"> selected="selected"</mt:if>><__trans phrase="Unpublished (Draft)"></option>
        <option value="3"<mt:if name="status_review"> selected="selected"</mt:if>><__trans phrase="Unpublished (Review)"></option>
      <mt:else>
        <option value="10" selected="selected"><__trans phrase="Published (Draft)"></option>
        <option value="20"><__trans phrase="Request Approve after Publish"></option>
      </mt:if>
    </mt:if>
    <mt:if name="status_unpublish">
      <option value="1"<mt:if name="status_draft"> selected="selected"</mt:if>><__trans phrase="Unpublished (Draft)"></option>
      <option value="3"><__trans phrase="Unpublished (Review)"></option>
    </mt:if>
    </select>
</__trans_section>
HERE
    $$template =~ s!$old!$new!;

    $old = <<HERE;
      <button
         name="status"
         type="submit"
         title="<mt:var name="button_title">"
         class="publish action primary button btn btn-primary mx-1">
        <mt:var name="button_text">
      </button>
HERE

    $old = quotemeta($old);
    $new = <<HERE;
<mt:unless name="hidden_button">
      <button
         name="status"
         type="submit"
         title="<mt:var name="button_title">"
         class="publish action primary button btn btn-primary mx-1">
        <mt:var name="button_text">
      </button>
</mt:unless>
HERE
    $$template =~ s!$old!$new!;

    $old = <<HERE;
<mt:if name="use_revision">
  <mtapp:setting
     id="revision-note"
     label="<__trans phrase="Change note">"
     label_class="top-label">
    <input type="text" name="revision-note" id="revision-note" class="form-control text full" value="<mt:var name="revision-note" escape="html">" />
  </mtapp:setting>
</mt:if>
HERE

    $old = quotemeta($old);
    $new = <<HERE;
<mt:unless name="hidden_button">
<mt:if name="use_revision">
  <mtapp:setting
     id="revision-note"
     label="<__trans phrase="Change note">"
     label_class="top-label">
    <input type="text" name="revision-note" id="revision-note" class="form-control text full" value="<mt:var name="revision-note" escape="html">" />
  </mtapp:setting>
</mt:if>
</mt:unless>
HERE
    $$template =~ s!$old!$new!;

    $old = <<HERE;
  function setSaveButtonText () {
      var selectedStatus = jQuery('select#status').val();
      if (selectedStatus == 2) {
          jQuery('button.publish').text('<mt:var name="publish_button_text">');
          jQuery('button.publish').attr('title', '<mt:var name="publish_button_title">');
      } else if (selectedStatus == 4) {
          jQuery('button.publish').text('<mt:var name="scheduled_button_text">');
          jQuery('button.publish').attr('title', '<mt:var name="scheduled_button_title">');
      } else {
          jQuery('button.publish').text('<mt:var name="draft_button_text">');
          jQuery('button.publish').attr('title', '<mt:var name="draft_button_title">');
      }
  }
HERE

my $review_button_text = $plugin->translate('Request Approve');
my $publish_review_button_text = $plugin->translate('Request Approve after Publish');

    $old = quotemeta($old);
    $new = <<HERE;
    function setSaveButtonText () {
        var selectedStatus = jQuery('select#status').val();
        if (selectedStatus == 3) {
            jQuery('#workflow-field').css('display','block');
            jQuery('button.publish').text('<mt:var name="draft_button_text">');
            jQuery('button.publish').attr('title', '<mt:var name="draft_button_title">');
            jQuery('.preview-action').hide();
        } else if (selectedStatus == 4) {
            jQuery('button.publish').text('<mt:var name="scheduled_button_text">');
            jQuery('button.publish').attr('title', '<mt:var name="scheduled_button_title">');
        } else if (selectedStatus == 10) {
            jQuery('#workflow-field').css('display','none');
            jQuery('button.publish').text('<mt:var name="draft_button_text">');
            jQuery('button.publish').attr('title', '<mt:var name="draft_button_title">');
            jQuery('#workflow-field').css('display','none');
            jQuery('.preview-action').show();
        } else if (selectedStatus == 20) {
            jQuery('#workflow-field').css('display','block');
            jQuery('button.publish').text('<mt:var name="draft_button_text">');
            jQuery('button.publish').attr('title', '<mt:var name="draft_button_title">');
            jQuery('.preview-action').hide();
        } else if (selectedStatus == 1) {
            jQuery('#workflow-field').css('display','none');
            jQuery('button.publish').text('<mt:var name="draft_button_text">');
            jQuery('button.publish').attr('title', '<mt:var name="draft_button_title">');
            jQuery('.preview-action').show();
} else if (selectedStatus == 50) {
    jQuery('#workflow-field').css('display','block');
    jQuery('button.publish').text('<mt:var name="scheduled_button_text">');
    jQuery('button.publish').attr('title', '<mt:var name="scheduled_button_title">');
    jQuery('.preview-action').hide();
        } else {
            jQuery('button.publish').text('<mt:var name="draft_button_text">');
            jQuery('button.publish').attr('title', '<mt:var name="draft_button_title">');
        }
    }

    jQuery('#status').on('change', function() {
        var changedStatus = jQuery('#status option:selected').val();
        if (changedStatus == 10 || changedStatus == 1 || changedStatus == 2 ) {
            jQuery('#workflow-field').css('display','none');
        } else {
            jQuery('#workflow-field').css('display','block');
        }
    });
HERE
        $$template =~ s!$old!$new!;

    # for 6.1
    $old = <<HERE;
  <mt:if name="config.previewinnewwindow">
    jQuery('button.publish').click(function(event) {
        jQuery('form#edit-content-type-data-form input[name=__mode]').val('save');
        jQuery('form#edit-content-type-data-form').removeAttr('target');
    });
  </mt:if>
HERE

    $old = quotemeta($old);
    $new = <<HERE;
  <mt:if name="config.previewinnewwindow">
    jQuery('button.publish').click(function(event) {
        jQuery('form#edit-content-type-data-form input[name=__mode]').val('save');
        jQuery('form#edit-content-type-data-form').removeAttr('target');
        var selectedStatus = jQuery('select#status').val();
        if (selectedStatus == 10 || selectedStatus == 20 || selectedStatus == 40 || selectedStatus > 2000) {
            jQuery('form#edit-content-type-data-form input[name=__mode]').val('save_snapshot_wf_cd');
        }
    });
  <mt:else>
    jQuery('button.publish').click(function(event) {
        var selectedStatus = jQuery('select#status').val();
        if (selectedStatus == 10 || selectedStatus == 20 || selectedStatus == 40 || selectedStatus > 2000) {
            jQuery('form#edit-content-type-data-form input[name=__mode]').val('save_snapshot_wf_cd');
        }
    });
  </mt:if>
HERE
        $$template =~ s!$old!$new!;

    } else {
##################### MT6
        $old = <<HERE;
    <select name="status" id="status" class="custom-select form-control full" onchange="highlightSwitch(this)">
      <option value="1"<mt:if name="status_draft"> selected="selected"</mt:if>><__trans phrase="Unpublished (Draft)"></option>
      <option value="2"<mt:if name="status_publish"> selected="selected"</mt:if>><__trans phrase="Published"></option>
    <mt:if name="status_review">
      <option value="3" selected="selected"><__trans phrase="Unpublished (Review)"></option>
    <mt:else name="status_spam">
      <option value="5" selected="selected"><__trans phrase="Unpublished (Spam)"></option>
    </mt:if>
    <mt:if name="new_object">
      <option value="4"<mt:if name="status_future"> selected="selected"</mt:if>><__trans phrase="Scheduled"></option>
    <mt:else>
      <mt:unless name="status_publish">
      <option value="4"<mt:if name="status_future"> selected="selected"</mt:if>><__trans phrase="Scheduled"></option>
      </mt:unless>
    </mt:if>
    <mt:if name="status_unpublish">
      <option value="6" selected="selected"><__trans phrase="Unpublished (End)"></option>
    </mt:if>
    </select>
HERE
##################### MT6
    $old = quotemeta($old);
    $new = <<HERE;
<mt:SetVar name="display_button" value="0" />
<mt:if name="status_review">
  <mt:SetVar name="display_button" value="1" />
</mt:if>
<mt:if name="status_publish_review">
  <mt:SetVar name="display_button" value="1" />
</mt:if>
<mt:if name="status_publish_scheduled">
  <mt:SetVar name="display_button" value="0" />
</mt:if>
<mt:if name="status_publish_publish_scheduled">
  <mt:SetVar name="display_button" value="0" />
</mt:if>
<__trans_section component="Workflow">
    <select<mt:unless name="display_button"> disabled="disabled"</mt:unless> name="status" id="status" class="custom-select form-control full" onchange="highlightSwitch(this)">
    <mt:if name="status_review">
      <option value="1"<mt:if name="status_draft"> selected="selected"</mt:if>><__trans phrase="No Approval"></option>
      <option value="2"<mt:if name="status_publish"> selected="selected"</mt:if>><__trans phrase="Approve"></option>
    <mt:else name="status_publish_scheduled">
      <option value="1"><__trans phrase="Scheduled"></option>
    <mt:else name="status_draft">
      <option value="1"><__trans phrase="Unpublished (Draft)"></option>
    <mt:else name="status_publish_draft">
      <option value="10" selected="selected"><__trans phrase="Published (Draft)"></option>
    <mt:else name="status_publish_review">
      <option value="40" selected="selected"><__trans phrase="No Approval"></option>
      <option value="2"><__trans phrase="Approve"></option>
    <mt:else name="status_publish">
      <option value="2"><__trans phrase="Approve"></option>
    </mt:if>
    <mt:if name="status_unpublish">
      <option value="6" selected="selected"><__trans phrase="Unpublished (End)"></option>
    </mt:if>
    </select>
</__trans_section>
HERE
    $$template =~ s!$old!$new!;

    $old = <<HERE;
      <button
         name="status"
         type="submit"
         title="<mt:var name="button_title">"
         class="publish action primary button btn btn-primary mx-1">
        <mt:var name="button_text">
      </button>
HERE

    $old = quotemeta($old);
    $new = <<HERE;
<mt:if name="display_button">
      <button
         name="status"
         type="submit"
         title="<mt:var name="button_title">"
         class="publish action primary button btn btn-primary mx-1">
        <mt:var name="button_text">
      </button>
</mt:if>
HERE
    $$template =~ s!$old!$new!;

    $old = <<HERE;
  function setSaveButtonText () {
      var selectedStatus = jQuery('select#status').val();
      if (selectedStatus == 2) {
          jQuery('button.publish').text('<mt:var name="publish_button_text">');
          jQuery('button.publish').attr('title', '<mt:var name="publish_button_title">');
      } else if (selectedStatus == 4) {
          jQuery('button.publish').text('<mt:var name="scheduled_button_text">');
          jQuery('button.publish').attr('title', '<mt:var name="scheduled_button_title">');
      } else {
          jQuery('button.publish').text('<mt:var name="draft_button_text">');
          jQuery('button.publish').attr('title', '<mt:var name="draft_button_title">');
      }
  }
HERE

    $old = quotemeta($old);

    $new = <<HERE;
    function setSaveButtonText () {
        var selectedStatus = jQuery('select#status').val();
        if (selectedStatus == 2) {
            jQuery('button.publish').text('<mt:var name="publish_button_text">');
            jQuery('button.publish').attr('title', '<mt:var name="publish_button_title">');
        } else if (selectedStatus == 3) {
            jQuery('button.publish').text('<mt:var name="review_button_text">');
            jQuery('button.publish').attr('title', '<mt:var name="review_button_title">');
        } else if (selectedStatus == 4) {
            jQuery('button.publish').text('<mt:var name="scheduled_button_text">');
            jQuery('button.publish').attr('title', '<mt:var name="scheduled_button_title">');
        } else if (selectedStatus == 30) {
            jQuery('button.publish').text('<mt:var name="button_text">');
            jQuery('button.publish').attr('title', '<mt:var name="button_title">');
        } else if (selectedStatus == 40) {
            jQuery('button.publish').text('<mt:var name="draft_button_text">');
            jQuery('button.publish').attr('title', '<mt:var name="draft_button_title">');
} else if (selectedStatus == 110) {
    jQuery('button.publish').text('<mt:var name="draft_button_text">');
    jQuery('button.publish').attr('title', '<mt:var name="draft_button_title">');
        } else {
            jQuery('button.publish').text('<mt:var name="draft_button_text">');
            jQuery('button.publish').attr('title', '<mt:var name="draft_button_title">');
        }
    }

    function change_message_field (changedStatus) {
        if (changedStatus == 10 || changedStatus == 40 || changedStatus == 1) {
            jQuery('#workflow-approve-message-field').css('display','none');
            jQuery('#workflow-no-approve-message-field').css('display','block');
            jQuery('#no_approve_message').prop("disabled", false);
            jQuery('#approve_message').prop("disabled", true);
        } else if (changedStatus == 2 || changedStatus == 4 || changedStatus == 110) {
            jQuery('#workflow-approve-message-field').css('display','block');
            jQuery('#workflow-no-approve-message-field').css('display','none');
            jQuery('#no_approve_message').prop("disabled", true);
            jQuery('#approve_message').prop("disabled", false);
        } else {
            jQuery('#workflow-approve-message-field').css('display','none');
            jQuery('#workflow-no-approve-message-field').css('display','block');
            jQuery('#no_approve_message').prop("disabled", false);
            jQuery('#approve_message').prop("disabled", true);
        }
    }

    // Xe[^X؂ւ̃bZ[WGA
    jQuery('select#status').on('change', function() {
        var changedStatus = jQuery('#status option:selected').val();
        change_message_field(changedStatus);
    });

    // y[Wǂݍݎ̃bZ[WGA
    var changedStatus = jQuery('select#status option:selected').val();
    change_message_field(changedStatus);
HERE

    $$template =~ s!$old!$new!;

    # for 6.1
    $old = <<HERE;
  <mt:if name="config.previewinnewwindow">
    jQuery('button.publish').click(function(event) {
        jQuery('form#edit-content-type-data-form input[name=__mode]').val('save');
        jQuery('form#edit-content-type-data-form').removeAttr('target');
    });
  </mt:if>
HERE

    $old = quotemeta($old);
    $new = <<HERE;
  <mt:if name="config.previewinnewwindow">
    jQuery('button.publish').click(function(event) {
        jQuery('form#edit-content-type-data-form input[name=__mode]').val('save');
        jQuery('form#edit-content-type-data-form').removeAttr('target');
        var selectedStatus = jQuery('select#status').val();
        if (selectedStatus == 10 || selectedStatus == 20 || selectedStatus == 40 || selectedStatus == 110) {
            jQuery('form#edit-content-type-data-form input[name=__mode]').val('save_snapshot_wf_cd');
        }
    });
  <mt:else>
    jQuery('button.publish').click(function(event) {
        var selectedStatus = jQuery('select#status').val();
        if (selectedStatus == 10 || selectedStatus == 20 || selectedStatus == 40 || selectedStatus == 110) {
            jQuery('form#edit-content-type-data-form input[name=__mode]').val('save_snapshot_wf_cd');
        }
    });
  </mt:if>
HERE
        $$template =~ s!$old!$new!;

    }

    $old = <<HERE;
</mt:setvarblock>

<mt:setvarblock name="css_include" append="1">
HERE
    $old = quotemeta($old);

    if ($reviewee) {

        my @authors = _get_authors($app, $plugin);
        my $address_list;
        foreach my $author (@authors) {
            $address_list .= '<li><input type="checkbox" name="address" id="address'.$author->{id}.'" value="author'.$author->{id}.'" checked="checked" class="cb" /> <label for="address'.$author->{id}.'">'.$author->{name}.'</label></li>';
        }
        if ($address_list) {
            $address_list = '<ul class="address_list">'.$address_list.'</ul>';
        } else {
            $address_list = $plugin->translate('No Address');
        }

        my $h2_message_request_approve = $plugin->translate('Request Approve');
        my $h2_message_resend_mail = $plugin->translate('Resend Mail');
        my $body_address_list_message = $plugin->translate('Address for Approval');
        my $mail_message = $plugin->translate('Approval note');
        my $resend_mail = $plugin->translate('Send Mail');

        my $body_start = <<HTML;
<mtapp:setting
    id="allow-feedback"
    label="$body_address_list_message"
    label_class="top-label"
    help_page="entries"
    help_section="workflow_mail">
    $address_list
</mtapp:setting>
<mtapp:setting
    id="approval-note"
    label="$mail_message"
    label_class="top-label">
HTML

        my $body_end = <<HTML;
</mtapp:setting>
HTML

        $new = <<HERE;
</mtapp:widget>

<mt:if name="status_review">
  <mt:var name="review" value="1" />
</mt:if>
<mt:if name="status_publish_review">
  <mt:var name="review" value="1" />
</mt:if>
<mt:unless name="review">
    <div id="workflow-field" style="display: none;">
        <mtapp:widget
            id="workflow-widget"
            label="$h2_message_request_approve">
            $body_start
    <textarea name="request_approve_message" class="form-control text full low" id="request_approve_message" cols="" rows=""><mt:var name="message" escape="html"></textarea>
            $body_end
        </mtapp:widget>
    </div>
<mt:else>
    <mt:unless name="error">

        <div id="workflow-field" style="display: none;">
            <mtapp:widget
                id="workflow-widget"
                label="$h2_message_resend_mail">
                $body_start
    <textarea name="resend_message" class="form-control text full low" id="resend_message" cols="" rows=""><mt:var name="message" escape="html"></textarea>
                $body_end
                <button
                    mt:mode="resend_mail_cd"
                    type="submit"
                    title="<__trans phrase="Send mail">"
                    class="save draft action button btn btn-default mx-1"
                    value="1"
                    >$resend_mail</button>
            </mtapp:widget>
        </div>

    </mt:unless>
</mt:unless>

</mt:setvarblock>

<mt:setvarblock name="css_include" append="1">
HERE

    } elsif ($reviewer) {

        my $top_message = $plugin->translate('Approve');
        my $message = $plugin->translate('Address for Approval');
        my $mail_message = $plugin->translate('No Approval note');

        my $top_preview_message = $plugin->translate('Request Preview');
        my $top_preview_message_review = $plugin->translate('Send Mail');
        my $preview_message = $plugin->translate('Address for Preview');
        my $preview_mail_message = $plugin->translate('Approval note');
        my $send_mail = $plugin->translate('Preview Mail');
        my $else_email = $plugin->translate('Else Email');

        my $iter = MT::AddressBook->load_iter( { blog_id => [ $app->blog->id, 0 ] });
        my $address_list;
        while (my $address = $iter->()) {
            $address_list .= '<li><input type="checkbox" name="address" id="address'.$address->id.'" value="address'.$address->id.'" checked="checked" class="cb" /> <label for="address'.$address->id.'">'.$address->name.'</label></li>';
        }
        if ($address_list) {
            $address_list = '<ul class="address_list">'.$address_list.'</ul>';
        } else {
            $address_list = $plugin->translate('No Address');
        }

        my $h2_message_request_approve = $plugin->translate('Request Approve');
        my $h2_message_resend_mail = $plugin->translate('Resend Mail');
        my $body_address_list_message = $plugin->translate('Address for Next approval');
        my $mail_message = $plugin->translate('Request approval message to next approver');
        my $resend_mail = $plugin->translate('Send Mail');

        my $body_start = <<HTML;
<mtapp:setting
    id="allow-feedback"
    label="$body_address_list_message"
    label_class="top-label"
    help_page="entries"
    help_section="workflow_mail">
$address_list
</mtapp:setting>
<mtapp:setting
    id="approval-note"
    label="$mail_message"
    label_class="top-label">
HTML

        my $body_end = <<HTML;
</mtapp:setting>
HTML

        $new = <<HERE;
<mt:if name="status_review">
  <mt:var name="review" value="0" />
</mt:if>
<mt:if name="status_publish_review">
  <mt:var name="review" value="0" />
</mt:if>
<mt:unless name="review">
        <div id="workflow-request-approve-field" style="display: none;">
            <mtapp:widget
                id="workflow-widget"
                label="$h2_message_request_approve">
                $body_start
    <textarea name="request_approve_message" class="form-control text full low" id="request_approve_message" cols="" rows=""><mt:var name="message" escape="html"></textarea>
                $body_end
            </mtapp:widget>
        </div>
</mt:unless>
HERE

        my $h2_approve_message = $plugin->translate('Approve');
        my $h2_no_approve_message = $plugin->translate('No Approval');
        my $h2_preview_message = $plugin->translate('Request Preview');
        my $h2_preview_message_review = $plugin->translate('Send Mail');

        my $approve_mail_message = $plugin->translate('Approval message to writer');
        my $no_approve_mail_message = $plugin->translate('No Approval message to writer');
        my $preview_message = $plugin->translate('Address for Preview');
        my $preview_mail_message = $plugin->translate('Approval note');
        my $send_mail = $plugin->translate('Preview Mail');
        my $else_email = $plugin->translate('Else Email');

        $new .= <<HERE;
<mt:if name="status_review">
  <mt:var name="review" value="1" />
</mt:if>
<mt:if name="status_publish_review">
  <mt:var name="review" value="1" />
</mt:if>
<mt:if name="review">

    <div id="workflow-approve-message-field" style="display: none;">
        <mtapp:widget
            id="workflow-widget"
            label="$h2_approve_message">
            <mtapp:setting
                id="approval-note"
                label="$approve_mail_message"
                label_class="top-label">
                <textarea name="approve_message" class="form-control text full low" cols="" rows="" id="approve_message"><mt:var name="message" escape="html"></textarea>
            </mtapp:setting>
        </mtapp:widget>
    </div>
    <div id="workflow-no-approve-message-field" style="display: none;">
        <mtapp:widget
            id="workflow-widget"
            label="$h2_no_approve_message">
            <mtapp:setting
                id="approval-note"
                label="$no_approve_mail_message"
                label_class="top-label">
                <textarea name="no_approve_message" class="form-control text full low" cols="" rows="" id="no_approve_message"><mt:var name="message" escape="html"></textarea>
            </mtapp:setting>
        </mtapp:widget>
    </div>

<div id="workflow-preview-field">
    <mtapp:widget
        id="workflow-widget"
        label="$h2_preview_message">

        <mtapp:setting
            id="preview-messag"
            label="$preview_message"
            label_class="top-label"
            help_page="entries"
            help_section="workflow_mail">
$address_list
        </mtapp:setting>
        <mtapp:setting
            id="else-email"
            label="$else_email"
            label_class="top-label"
            help_page="entries"
            help_section="workflow_mail">
<input type="text" id="else_email" name="else_email" class="form-control text full" />
        </mtapp:setting>
        <mtapp:setting
            id="approval-note"
            label="$preview_mail_message"
            label_class="top-label">
            <textarea name="preview_message" class="form-control text full low" cols="" rows="" id="preview_message"><mt:var name="preview_message" escape="html"></textarea>
        </mtapp:setting>
        <button
            mt:mode="request_preview_mail_cd"
            type="submit"
            title="<__trans phrase="Send mail">"
            class="save draft action button btn btn-default mx-1"
            value="1"
            >$send_mail</button>
    </mtapp:widget>
</div>
</mt:if>
</mtapp:widget>
</mt:setvarblock>

<mt:setvarblock name="css_include" append="1">
HERE
    }

    $$template =~ s!$old!$new!;

    my $workflow_display_delete_button = $plugin->get_config_value('workflow_display_delete_button', 'blog:' . $app->blog->id);

    if ($reviewee && !$workflow_display_delete_button) {
    $old = <<HERE;
<mt:if name="id">
<div class="text-right delete-action">
  <a
     href="javascript:void(0)"
     mt:command="do-remove-items"
     mt:object-singular="<mt:var name="object_label" lower_case="1" escape="html">"
     mt:object-plural="<mt:var name="object_label_plural" lower_case="1" escape="html">"
     mt:subtype="content_data_<mt:var name="content_type_id" escape="html">"
     mt:object-type="content_data"
     mt:blog-id="<mt:var name="blog_id">"
     title="<mt:var name="delete_button_title">"
     class="delete"
     accesskey="x">
    <mtapp:svgicon id="ic_trash" size="sm" title="\$delete_button_title">
    <__trans phrase="Delete">
  </a>
</div>
</mt:if>
HERE
    $old = quotemeta($old);

    $$template =~ s!$old!!;
    }
}

sub itemset_action_widget {
    my ($cb, $app, $template) = @_;

    return if !can_workflow($app);

    my $q = $app->{query};
    my $blog_id = $q->param('blog_id');

    my $plugin = MT->component('Workflow');
    my $workflow_display_unpublish_option = $plugin->get_config_value('workflow_display_unpublish_option', 'blog:' . $blog_id);
    my $reviewee = $app->can_do('request_entry_approval');

    if ($reviewee && !$workflow_display_unpublish_option) {

    my $old = <<HERE;
<select name="plugin_action_selector" onchange="updatePluginAction(this)">
    <option value="0"><__trans phrase="More actions..."></option>
    <mt:loop name="list_actions">
    <option value="<mt:var name="key">"><mt:var name="label"></option>
    </mt:loop>
    <mt:loop name="more_list_actions">
        <mt:if name="__first__">
    <optgroup label="<__trans phrase='Plugin Actions'>">
        </mt:if>
        <option value="<mt:var name="key">"><mt:var name="label"></option>
        <mt:if name="__last__">
    </optgroup>
        </mt:if>
    </mt:loop>
</select>
<mt:if name="form_id">
<button
     class="small-button mt-<mt:var name="form_id">-action"
     ><__trans phrase="Go"></button>
<mt:else>
<button
     class="small-button mt-<mt:var name="object_type">-listing-form-action"
     ><__trans phrase="Go"></button>
</mt:if>
HERE
    $old = quotemeta($old);

    $$template =~ s!$old!!;

    }
}

sub _get_authors {
    my ($app, $plugin) = @_;

    require MT::Association;
    require MT::Role;
    my $blog = $app->blog;

    my $role_name = $plugin->translate('Approver');
    my $role = MT::Role->load( { name => $role_name } );
    my $role_id = $role->id;

    my $iter = MT::Author->load_iter(undef, {
                              join => MT::Association->join_on('author_id', {
                                  role_id => $role_id,
                                  blog_id => $blog->id
                              }, { unique => 1 })
                          });

    my @authors;
    while (my $author = $iter->()) {
        push(@authors, { id => $author->id, name => $author->name });
    }
    return @authors;
}

1;
