package Workflow::Util;

use strict;
use warnings;

use Exporter;
@Workflow::Util::ISA = qw( Exporter );
use vars qw( @EXPORT_OK );
@EXPORT_OK = qw( can_workflow use_revision get_lastest_revision get_lastest_revision_object use_revision_cd get_lastest_revision_cd get_lastest_revision_for_future_post get_lastest_revision_object_for_future_post get_lastest_revision_for_future_post_cd );

sub can_workflow {
    my $app = shift;

#    my $plugin = MT->component('Workflow');
#    my $superuser = $plugin->get_config_value('no_use_for_superuser', 'blog:' . $app->blog->id);
#    return if $superuser;

    my $author = $app->user;
    return 0 if $author->is_superuser();

    my $reviewee = $app->can_do('request_entry_approval');
    my $reviewer = $app->can_do('approve_entry');

    return 0 unless ($reviewer || $reviewee);

    1;
}

sub use_revision {
    my $app = shift;

    my $q = $app->param;

    my $reviewee = $app->can_do('request_entry_approval');
    my $reviewer = $app->can_do('approve_entry');
    my $use_revision = 0;
    $use_revision = 1 if $reviewer || $reviewee;

    my $id = $q->param('id');
    if (!$id) {
        $use_revision = 0 if $reviewer;
    } else {
        my $entry = MT::Entry->load($id);
        my $entry_author = MT::Author->load($entry->author_id);

        # F
        if ($reviewer) {
            my $author = $app->user;
            if ($entry->author_id eq $author->id) {

                # FҎg̋L̓[Nt[ΏۊO
                $use_revision = 0;
            }

        # C^[/̑
        } else {
            my $perms = $entry_author->permissions($entry->blog_id);

            # L쐬҂̌C^[ȊȌꍇ̓[Nt[ΏۊO
            $use_revision = 0 if !$perms->can_do("request_entry_approval");
        }

        # VXeǗ҂̓[Nt[ΏۊO
        $use_revision = 0 if $app->user->is_superuser;

        # VXeǗ҂̋L̓[Nt[ΏۊO
        $use_revision = 0 if $entry_author->is_superuser();
    }

    return $use_revision;
}

sub get_lastest_revision {
    my $app = shift;

    my $q    = $app->param;
    my $type = $q->param('_type');
    my $id   = $q->param('id');

    my ($terms, $args);
    $terms->{entry_id} = $id;
    $args->{sort} = 'rev_number';
    $args->{direction} = 'descend';
    $args->{limit} = 1;
    my $rev_model = $app->model($type.':revision');
    my @revs = $rev_model->load($terms, $args);
    my $revision = shift @revs || undef;

    # for upgrade from without revision function.
    if ( !defined $revision ){
        my $entry = MT::Entry->load($id);
        return undef if !$entry;

        my @changed_cols;
        my $revisioned_cols = $entry->revisioned_columns;
        foreach my $col (@$revisioned_cols) {
            push @changed_cols, $col;
        }
        $entry->{changed_revisioned_cols} = \@changed_cols;
        my $revision_number = $entry->save_revision('for Workflow');

        @revs = $rev_model->load($terms, $args);
        $revision = shift @revs || undef;
    }

    return $revision;
}

sub get_lastest_revision_object {
    my ($app, $revision) = @_;

    my $q    = $app->param;
    my $type = $q->param('_type'); #'entry';
    my $id   = $q->param('id');

    my @objs = $app->model($type)->load($id);
    my $obj = shift @objs || undef;
    return $app->error( "No Object." ) if !$obj;

    my $rev = $obj->load_revision( { rev_number => $revision->rev_number } );
    if ( $rev && @$rev ) {
        $obj = $rev->[0];
    }
}
sub use_revision_cd {
    my $app = shift;

    my $q = $app->param;

    my $reviewee = $app->can_do('request_entry_approval');
    my $reviewer = $app->can_do('approve_entry');
    my $use_revision = 0;
    $use_revision = 1 if $reviewer || $reviewee;

    my $blog_id = $q->param('blog_id');
    my $content_type_id = $q->param('content_type_id');
    my $id = $q->param('id');

    if (!$id) {
        $use_revision = 0 if $reviewer;
        $use_revision = 1 if $reviewee;
    } else {
        my $entry = MT::ContentData->load(
            {   id              => $id,
                blog_id         => $blog_id,
                content_type_id => $content_type_id,
            });
        my $entry_author = MT::Author->load($entry->author_id);

        # F
        if ($reviewer) {
            my $author = $app->user;
            if ($entry->author_id eq $author->id) {

                # FҎg̋L̓[Nt[ΏۊO
                $use_revision = 0;
            }

        # C^[/̑
        } else {
            my $perms = $entry_author->permissions($entry->blog_id);

            # L쐬҂̌C^[ȊȌꍇ̓[Nt[ΏۊO
            $use_revision = 0 if !$perms->can_do("request_entry_approval");
        }

        # VXeǗ҂̓[Nt[ΏۊO
        $use_revision = 0 if $app->user->is_superuser;

        # VXeǗ҂̋L̓[Nt[ΏۊO
        $use_revision = 0 if $entry_author->is_superuser();
    }

    return $use_revision;
}

sub get_lastest_revision_cd {
    my $app = shift;

    my $q    = $app->param;
    my $type = $q->param('_type');
    my $id   = $q->param('id');

    my ($terms, $args);
    $terms->{cd_id} = $id;
    $args->{sort} = 'rev_number';
    $args->{direction} = 'descend';
    $args->{limit} = 1;
    my $rev_model = $app->model($type.':revision');
    my @revs = $rev_model->load($terms, $args);
    my $revision = shift @revs || undef;

    # for upgrade from without revision function.
    if ( !defined $revision ){
        my $entry = MT::ContentData->load($id);
        return undef if !$entry;

        my @changed_cols;
        my $revisioned_cols = $entry->revisioned_columns;
        foreach my $col (@$revisioned_cols) {
            push @changed_cols, $col;
        }
        $entry->{changed_revisioned_cols} = \@changed_cols;
        my $revision_number = $entry->save_revision('for Workflow');

        @revs = $rev_model->load($terms, $args);
        $revision = shift @revs || undef;
    }

    return $revision;
}


1;
